rem RPC-320 binary data save and load demonstration program

rem RPC-320 must have at least 128K of RAM and 512K of flash EPROM in
rem order for this demonstration program to work.

rem Program explaination
rem Lines 10-30 write data to RAM that will be saved to flash EPROM
rem In this case, it is simply a sequence of numbers 0 to 1000

rem Line 40 sets the flash EPROM address to save to.  Note it is
rem on a 512 byte boundary, as explained in the manual.

rem Lines 50-70 clear out a RAM area the BLOAD command will put the
rem information to.  This is not necessary for most applications.  The
rem reason this is done here is to test binary save and load programs
rem to make sure data has been transferred accurately.

rem Line 100 saves information to EPROM in segment 6.  The address
rem it is saved to in EPROM is determined by variable RA.

rem Line 200 loads data from EPROM to RAM.  In this case, it will put
rem it in RAM segment 1, address 2000.  Data was taken from EPROM segment
rem 6.  Again, the address is determined by variable RA.  Note that 1002
rem bytes are getting retrieved.  The BSAVE command actually wrote out
rem 1024 bytes.  900 bytes could have been specified, and 1024 bytes
rem still could have been written out.  If 500 bytes were specified, the
rem 512 bytes would have been written out.  This is because BSAVE must
rem save data to the 512K flash EPROM in 512 byte blocks.  1002 bytes
rem are retrieved because the FOR-NEXT loop at lines 10-30 wrote that many.

rem Lines 300 to 330 verify the information was transferred properly.



10     FOR N=0 TO 1000 STEP 2
20     POKE W1,N,N
30     NEXT 

40    RA=512

50     FOR N=2000 TO 3000 STEP 2
60     POKE W1,N,0
70     NEXT 

100   BSAVE6,RA,1,0,1000
200   BLOAD1,2000,6,RA,1002

300    FOR N=0 TO 1000 STEP 2
310   B=PEEKW(1,N+2000)
320    IF B<>N THEN  PRINT "Error address",N," data is",B
330    NEXT 
